# Table of Contents

- [updating-lifecycle-phase-and-approving-quality-seal](<./updating-lifecycle-phase-and-approving-quality-seal.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Updating a Lifecycle Phase and Approving the Quality Seal](<./Updating-a-Lifecycle-Phase-and-Approving-the-Quality-Seal.md>)
  - [Overview](<./Updating-a-Lifecycle-Phase-and-Approving-the-Quality-Seal/Overview.md>)
  - [Configuration](<./Updating-a-Lifecycle-Phase-and-Approving-the-Quality-Seal/Configuration.md>)
  - [Script](<./Updating-a-Lifecycle-Phase-and-Approving-the-Quality-Seal/Script.md>)
